==> jc-1.4.0.tar.gz: soot/jimple/spark/AbstractSparkTransformer.h <==
// public abstract class soot.jimple.spark.AbstractSparkTransformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 120bc7bd95b93244 soot_jimple_spark_AbstractSparkTransformer

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_spark_AbstractSparkTransformer_H_
#define _JC_soot_jimple_spark_AbstractSparkTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_tagkit_Host$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	_jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	_jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$refs	_jc_soot_jimple_spark_AbstractSparkTransformer$refs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs	_jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$object	_jc_soot_jimple_spark_AbstractSparkTransformer$object;

typedef const struct _jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods;
typedef const struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtable	_jc_soot_jimple_spark_AbstractSparkTransformer$vtable;
typedef const struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtype	_jc_soot_jimple_spark_AbstractSparkTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$addTag$5fbc5c285ef6ba7c(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$findSetMass$e803d2e09b4c02a1(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_AbstractSparkTransformer$method_info$addTag$5fbc5c285ef6ba7c;
extern _jc_method _jc_soot_jimple_spark_AbstractSparkTransformer$method_info$findSetMass$e803d2e09b4c02a1;

// Static methods
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$doGC$0070643976a2b3ac(_jc_env *);
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$reportTime$00b540c747740a68(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Date$object *, struct _jc_java_util_Date$object *);

// Virtual methods structure
struct _jc_soot_jimple_spark_AbstractSparkTransformer$vmethods {
	void	(*addTag$5fbc5c285ef6ba7c)(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_object *, struct _jc_object *);
	void	(*findSetMass$e803d2e09b4c02a1)(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *);
};

// Vtable
struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	soot_jimple_spark_AbstractSparkTransformer;
};

// Vtype
struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$refs {
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	soot_jimple_spark_AbstractSparkTransformer;
};

// Object instance structure
struct _jc_soot_jimple_spark_AbstractSparkTransformer$object {
	_jc_soot_jimple_spark_AbstractSparkTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vtype	*vtype;
	_jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_AbstractSparkTransformer$vtype _jc_soot_jimple_spark_AbstractSparkTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_AbstractSparkTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_AbstractSparkTransformer$class_object;

#endif	/* _JC_soot_jimple_spark_AbstractSparkTransformer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/AbstractSparkTransformer.h <==
// public abstract class soot.jimple.spark.AbstractSparkTransformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 120bc7bd95b93244 soot_jimple_spark_AbstractSparkTransformer

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_spark_AbstractSparkTransformer_H_
#define _JC_soot_jimple_spark_AbstractSparkTransformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_tagkit_Host$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	_jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	_jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$refs	_jc_soot_jimple_spark_AbstractSparkTransformer$refs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs	_jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs;
typedef struct _jc_soot_jimple_spark_AbstractSparkTransformer$object	_jc_soot_jimple_spark_AbstractSparkTransformer$object;

typedef const struct _jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods;
typedef const struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtable	_jc_soot_jimple_spark_AbstractSparkTransformer$vtable;
typedef const struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtype	_jc_soot_jimple_spark_AbstractSparkTransformer$vtype;

// Constructors
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$addTag$5fbc5c285ef6ba7c(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$findSetMass$e803d2e09b4c02a1(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_AbstractSparkTransformer$method_info$addTag$5fbc5c285ef6ba7c;
extern _jc_method _jc_soot_jimple_spark_AbstractSparkTransformer$method_info$findSetMass$e803d2e09b4c02a1;

// Static methods
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$doGC$0070643976a2b3ac(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_AbstractSparkTransformer$method$reportTime$00b540c747740a68(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Date$object *, struct _jc_java_util_Date$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_AbstractSparkTransformer$vmethods {
	void	(*addTag$5fbc5c285ef6ba7c)(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_object *, struct _jc_soot_jimple_spark_pag_Node$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*findSetMass$e803d2e09b4c02a1)(_jc_env *, struct _jc_soot_jimple_spark_AbstractSparkTransformer$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vmethods	soot_jimple_spark_AbstractSparkTransformer;
};

// Vtype
struct _jc_soot_jimple_spark_AbstractSparkTransformer$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$refs {
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_refs	soot_jimple_spark_AbstractSparkTransformer;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_spark_AbstractSparkTransformer$sub_nonrefs	soot_jimple_spark_AbstractSparkTransformer;
};

// Object instance structure
struct _jc_soot_jimple_spark_AbstractSparkTransformer$object {
	_jc_soot_jimple_spark_AbstractSparkTransformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_AbstractSparkTransformer$vtype	*vtype;
	_jc_soot_jimple_spark_AbstractSparkTransformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_AbstractSparkTransformer$vtype _jc_soot_jimple_spark_AbstractSparkTransformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_AbstractSparkTransformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_AbstractSparkTransformer$class_object;

#endif	/* _JC_soot_jimple_spark_AbstractSparkTransformer_H_ */
